@@ -23,6 +23,21 @@ import pyutilib.th as unittest
 from pyutilib.autotest import plugins
 
 
+# GAH: Inside create_test_suite all options are (were) being cast to
+#      str(). Although I'm not sure, I assume this is to wash out
+#      unicode coming from json files in Python 2.x. However, we don't
+#      want to cast numeric options in either case (which was happening, 
+#      e.g., tolerance). This is my quick hack to fix things. Please
+#      fix if you have a better understanding of what should be happening..
+try:
+    unicode
+except:
+    basestring = str
+def _str(x):
+    if isinstance(x,basestring):
+        return str(x)
+    return x
+
 def validate_test_config(suite):
     if suite is None:
         raise IOError("Empty suite indicates problem processing suite configuration")
@@ -181,10 +196,10 @@ def create_test_suite(suite, config, _globals, options):
         else:
             _problem = problem
         for attr,value in config['problems'].get(_problem,{}).items():
-            _options[attr] = str(value)
+            _options[attr] = _str(value)
         if not problem_options is None:
             for attr,value in problem_options.items():
-                _options[attr] = str(value)
+                _options[attr] = _str(value)
         #
         solver_options = config['suites'][suite]['solvers'][solver]
         if not solver_options is None and 'solver' in solver_options:
@@ -193,21 +208,21 @@ def create_test_suite(suite, config, _globals, options):
             _solver = solver
         _name = _solver
         for attr,value in config['solvers'].get(_solver,{}).items():
-            _options[attr] = str(value)
+            _options[attr] = _str(value)
             if attr == 'name':
                 _name = value
         if not solver_options is None:
             for attr,value in solver_options.items():
-                _options[attr] = str(value)
+                _options[attr] = _str(value)
         #
         for key in item:
             if key not in ['problem','solver']:
-                _options[key] = str(item[key])
+                _options[key] = _str(item[key])
         #
-        _options.solver = str(_name)
-        _options.problem = str(_problem)
-        _options.suite = str(suite)
-        _options.currdir = str(options.currdir)
+        _options.solver = _str(_name)
+        _options.problem = _str(_problem)
+        _options.suite = _str(suite)
+        _options.currdir = _str(options.currdir)
         #
         _globals[suite].add_fn_test(name=test_name, fn=fn, suite=suite, options=_options)
 
